@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -81,28 +81,31 @@ public class LocaleNames_es_MX extends OpenListResourceBundle {
             { "155", "Europa Occidental" },
             { "BA", "Bosnia y Herzegovina" },
             { "CI", "C\u00f4te d\u2019Ivoire" },
-            { "EZ", "zona euro" },
             { "GG", "Guernsey" },
             { "RO", "Rumania" },
             { "SA", "Arabia Saudita" },
             { "SZ", "Eswatini" },
             { "TA", "Trist\u00e1n de Acu\u00f1a" },
             { "UM", "Islas menores alejadas de EE. UU." },
-            { "UN", "ONU" },
             { "eu", "euskera" },
             { "lo", "lao" },
             { "nr", "ndebele meridional" },
             { "pa", "punyab\u00ed" },
             { "ss", "siswati" },
             { "sw", "suajili" },
-            { "tn", "setswana" },
             { "ace", "acehn\u00e9s" },
+            { "ady", "adigu\u00e9" },
             { "arp", "arapaho" },
+            { "ars", "\u00e1rabe neyed\u00ed" },
             { "bas", "basa" },
             { "bax", "bamun" },
             { "bho", "bhoshpuri" },
             { "bla", "siksika" },
             { "bua", "buriat" },
+            { "crj", "cree del sureste" },
+            { "crl", "cree del noreste" },
+            { "crr", "carolina algonquian" },
+            { "dar", "darguin" },
             { "dum", "neerland\u00e9s medieval" },
             { "enm", "ingl\u00e9s medieval" },
             { "frm", "franc\u00e9s medieval" },
@@ -110,28 +113,31 @@ public class LocaleNames_es_MX extends OpenListResourceBundle {
             { "gmh", "alem\u00e1n de la alta edad media" },
             { "grc", "griego antiguo" },
             { "hak", "kejia (China)" },
+            { "hax", "haida del sur" },
             { "hil", "hiligain\u00f3n" },
             { "hsn", "xiang (China)" },
+            { "ikt", "inuktitut del oeste de Canad\u00e1" },
             { "inh", "ingusetio" },
             { "kbd", "kabardiano" },
+            { "kgp", "kaingang" },
             { "krc", "karach\u00e1i b\u00e1lkaro" },
             { "kum", "cumuco" },
-            { "lus", "lushai" },
             { "mga", "irland\u00e9s medieval" },
             { "nan", "min nan (Chino)" },
             { "nso", "sotho septentrional" },
+            { "ojb", "ojibwa del noroeste" },
+            { "ojw", "ojibwa del oeste" },
             { "shu", "\u00e1rabe chadiano" },
+            { "slh", "lushootseed del sur" },
             { "syr", "siriaco" },
-            { "tet", "tet\u00fan" },
-            { "tyv", "tuviniano" },
+            { "tce", "tutchone del sur" },
             { "wuu", "chino wu" },
-            { "xal", "kalmyk" },
             { "zgh", "tamazight marroqu\u00ed est\u00e1ndar" },
-            { "Hanb", "hanb" },
-            { "Mlym", "malay\u00e1lam" },
             { "sw_CD", "suajili del Congo" },
             { "type.ca.roc", "calendario minguo" },
             { "type.nu.gujr", "d\u00edgitos en gujarati" },
+            { "type.nu.mtei", "d\u00edgitos en manipuri" },
+            { "type.nu.olck", "d\u00edgitos ol chiki" },
             { "type.co.ducet", "orden de clasificaci\u00f3n de Unicode predeterminado" },
         };
         return data;
